@@ -15,7 +15,8 @@ from .material import EnergyMaterial, EnergyMaterialNoMass, \
 from .programtype import ProgramTypeAbridged, ProgramType
 from .load import PeopleAbridged, LightingAbridged, ElectricEquipmentAbridged, \
     GasEquipmentAbridged, InfiltrationAbridged, VentilationAbridged, SetpointAbridged
-from .ventcool import VentilationControlAbridged, VentilationOpening
+from .ventcool import VentilationControlAbridged, VentilationOpening, \
+    VentilationSimulationControl, AFNCrack
 from .schedule import ScheduleTypeLimit, ScheduleRulesetAbridged, \
     ScheduleFixedIntervalAbridged, ScheduleRuleset, ScheduleFixedInterval
 from .hvac.idealair import IdealAirSystemAbridged
@@ -109,6 +110,12 @@ class FaceEnergyPropertiesAbridged(NoExtraBaseModel):
         'Model global_construction_set.'
     )
 
+    vent_crack: AFNCrack = Field(
+        default=None,
+        description='An optional AFNCrack to specify airflow through a surface crack '
+        'used by the AirflowNetwork.'
+    )
+
 
 class RoomEnergyPropertiesAbridged(NoExtraBaseModel):
 
@@ -238,3 +245,9 @@ class ModelEnergyProperties(NoExtraBaseModel):
         description='A list of all unique ScheduleTypeLimits in the model. This '
         'all ScheduleTypeLimits needed to make the Model schedules.'
     )
+
+    ventilation_simulation_control: VentilationSimulationControl = Field(
+        default=None,
+        description='An optional parameter to define the global parameters for '
+        'a ventilation cooling.'
+    )
\ No newline at end of file
