@@ -20,6 +20,7 @@ from honeybee_energy.load.setpoint import Setpoint
 from honeybee_energy.ventcool.opening import VentilationOpening
 from honeybee_energy.ventcool.control import VentilationControl
 from honeybee_energy.ventcool import afn
+from honeybee_energy.ventcool.simulation import VentilationSimulationControl
 from honeybee_energy.hvac.allair.vav import VAV
 from honeybee_energy.hvac.doas.fcu import FCUwithDOAS
 from honeybee_energy.hvac.heatcool.windowac import WindowAC
@@ -92,7 +93,7 @@ def model_complete_single_zone_office(directory):
 
     model = Model('Tiny_House', [room], orphaned_shades=[tree_canopy])
 
-    dest_file = os.path.join(directory, 'model_complete_single_zone_office.json')
+    dest_file = os.path.join(directory, 'model_complete_single_zone_office.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(), fp, indent=4)
 
@@ -137,7 +138,7 @@ def model_complete_single_zone_office_user_data(directory):
     model_dict['rooms'][0]['faces'][3]['apertures'][0]['outdoor_shades'][0]['user_data'] = \
         {'alt_name': 'Awning'}
 
-    dest_file = os.path.join(directory, 'model_complete_user_data.json')
+    dest_file = os.path.join(directory, 'model_complete_user_data.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(), fp, indent=4)
 
@@ -180,7 +181,7 @@ def model_complete_multi_zone_office(directory):
 
     model = Model('Multi_Zone_Single_Family_House', [first_floor, second_floor, attic])
 
-    dest_file = os.path.join(directory, 'model_complete_multi_zone_office.json')
+    dest_file = os.path.join(directory, 'model_complete_multi_zone_office.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(), fp, indent=4)
 
@@ -219,7 +220,7 @@ def model_complete_patient_room(directory):
 
     model = Model('Patient_Room_Test_Box', [room])
 
-    dest_file = os.path.join(directory, 'model_complete_patient_room.json')
+    dest_file = os.path.join(directory, 'model_complete_patient_room.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(), fp, indent=4)
 
@@ -249,7 +250,7 @@ def model_complete_office_floor(directory):
 
     model = Model('Core_Perimeter_Office_Floor', rooms)
 
-    dest_file = os.path.join(directory, 'model_complete_office_floor.json')
+    dest_file = os.path.join(directory, 'model_complete_office_floor.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(), fp, indent=4)
 
@@ -278,7 +279,7 @@ def model_complete_holes(directory):
 
     model = Model('Donut_Building', [room], orphaned_shades=[shd])
 
-    dest_file = os.path.join(directory, 'model_complete_holes.json')
+    dest_file = os.path.join(directory, 'model_complete_holes.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(), fp, indent=4)
 
@@ -302,7 +303,7 @@ def model_energy_shoe_box(directory):
 
     model = Model('Shoe_Box', [room])
 
-    dest_file = os.path.join(directory, 'model_energy_shoe_box.json')
+    dest_file = os.path.join(directory, 'model_energy_shoe_box.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(included_prop=['energy']), fp, indent=4)
 
@@ -328,7 +329,7 @@ def model_energy_detailed_loads(directory):
     model = Model('Office_Model', [room])
 
     dest_file = os.path.join(
-        directory, 'model_energy_detailed_loads.json')
+        directory, 'model_energy_detailed_loads.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(included_prop=['energy']), fp, indent=4)
 
@@ -382,7 +383,7 @@ def model_energy_fixed_interval(directory):
     model = Model('Tiny_House', [room], orphaned_shades=[tree_canopy])
 
     dest_file = os.path.join(
-        directory, 'model_energy_fixed_interval.json')
+        directory, 'model_energy_fixed_interval.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(included_prop=['energy']), fp, indent=4)
 
@@ -430,7 +431,7 @@ def model_energy_no_program(directory):
 
     model = Model('Tiny_House', [room], orphaned_shades=[tree_canopy])
 
-    dest_file = os.path.join(directory, 'model_energy_no_program.json')
+    dest_file = os.path.join(directory, 'model_energy_no_program.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(included_prop=['energy']), fp, indent=4)
 
@@ -459,28 +460,58 @@ def model_energy_window_ventilation(directory):
 
     model = Model('TinyHouse', [room])
 
-    dest_file = os.path.join(directory, 'model_energy_window_ventilation.json')
+    dest_file = os.path.join(directory, 'model_energy_window_ventilation.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(included_prop=['energy']), fp, indent=4)
 
 
 def model_energy_afn_multizone(directory):
 
-    # South Room
+    # south Room
     szone_pts = Face3D(
         [Point3D(0, 0), Point3D(20, 0), Point3D(20, 10), Point3D(0, 10)])
     sroom = Room.from_polyface3d(
         'SouthRoom', Polyface3D.from_offset_face(szone_pts, 3))
 
-    # North Room
+    # north Room
     nzone_pts = Face3D(
         [Point3D(0, 10), Point3D(20, 10), Point3D(20, 20), Point3D(0, 20)])
     nroom = Room.from_polyface3d(
         'NorthRoom', Polyface3D.from_offset_face(nzone_pts, 3))
 
-    # Add adjacent interior windows
-    sroom[3].apertures_by_ratio(0.3)  # Window on south face
-    nroom[1].apertures_by_ratio(0.3)  # Window on north face
+    # add exterior windows on east/west faces
+    sroom[2].apertures_by_ratio(0.3)
+    nroom[4].apertures_by_ratio(0.3)
+    sroom[2].apertures[0].is_operable = True
+    nroom[4].apertures[0].is_operable = True
+
+    # add small interior windows on north/south faces
+    sroom[3].apertures_by_ratio(0.15)
+    nroom[1].apertures_by_ratio(0.15)
+    sroom[3].apertures[0].is_operable = True
+    nroom[1].apertures[0].is_operable = True
+
+    # ventilation openings
+    vent_openings = VentilationOpening(
+        fraction_area_operable=1, fraction_height_operable=1, discharge_coefficient=0.6,
+        wind_cross_vent=False, flow_coefficient_closed=0.001, flow_exponent_closed=0.667,
+        two_way_threshold=0.0001)
+
+    sroom.properties.energy.assign_ventilation_opening(vent_openings)
+    nroom.properties.energy.assign_ventilation_opening(vent_openings.duplicate())
+
+    # make ventilation control
+    heat_setpt = ScheduleRuleset.from_constant_value(
+        'House Heating', 20, schedule_types.temperature)
+    cool_setpt = ScheduleRuleset.from_constant_value(
+        'House Cooling', 28, schedule_types.temperature)
+    setpoint = Setpoint('House Setpoint', heat_setpt, cool_setpt)
+    sroom.properties.energy.setpoint = setpoint
+    nroom.properties.energy.setpoint = setpoint.duplicate()
+
+    vent_control = VentilationControl(22, 27, 12, 30)
+    sroom.properties.energy.window_vent_control = vent_control
+    nroom.properties.energy.window_vent_control = vent_control.duplicate()
 
     # rooms
     rooms = [sroom, nroom]
@@ -488,17 +519,20 @@ def model_energy_afn_multizone(directory):
         # Add program and hvac
         room.properties.energy.program_type = prog_type_lib.office_program
 
-    # Make model
+    # make model
     model = Model('Two_Zone_Simple', rooms)
+    vsc = VentilationSimulationControl(
+        vent_control_type='MultiZoneWithoutDistribution', building_type='LowRise',
+        long_axis_angle=0, aspect_ratio=1)
+    model.properties.energy.ventilation_simulation_control = vsc
 
-    # Make interior faces
+    # make interior faces
     Room.solve_adjacency(rooms, 0.01)
 
-    # Make afn
-    window_vent_controls = [VentilationControl().duplicate() for _ in rooms]
-    afn.generate(model.rooms, window_vent_controls)
+    # make afn
+    afn.generate(model.rooms)
 
-    dest_file = os.path.join(directory, 'model_energy_afn.json')
+    dest_file = os.path.join(directory, 'model_energy_afn.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(included_prop=['energy']), fp, indent=4)
 
@@ -526,7 +560,7 @@ def model_energy_allair_hvac(directory):
     Room.solve_adjacency([first_floor, second_floor], 0.01)
     model = Model('Model_Energy_Allair_HVAC', [first_floor, second_floor])
 
-    dest_file = os.path.join(directory, 'model_energy_allair_hvac.json')
+    dest_file = os.path.join(directory, 'model_energy_allair_hvac.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(included_prop=['energy']), fp, indent=4)
 
@@ -552,7 +586,7 @@ def model_energy_doas_hvac(directory):
     Room.solve_adjacency([first_floor, second_floor], 0.01)
     model = Model('Model_Energy_DOAS_HVAC', [first_floor, second_floor])
 
-    dest_file = os.path.join(directory, 'model_energy_doas_hvac.json')
+    dest_file = os.path.join(directory, 'model_energy_doas_hvac.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(included_prop=['energy']), fp, indent=4)
 
@@ -577,24 +611,11 @@ def model_energy_window_ac(directory):
     Room.solve_adjacency([first_floor, second_floor], 0.01)
     model = Model('Model_Energy_Window_AC', [first_floor, second_floor])
 
-    dest_file = os.path.join(directory, 'model_energy_window_ac.json')
+    dest_file = os.path.join(directory, 'model_energy_window_ac.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(included_prop=['energy']), fp, indent=4)
 
 
-def model_energy_properties_office(directory):
-    room = Room.from_box('Closed_Office', 5, 10, 3)
-    room.properties.energy.program_type = prog_type_lib.office_program
-    room.properties.energy.add_default_ideal_air()
-
-    model = Model('Office_Test_Box', [room])
-    model_dict = model.to_dict()
-
-    dest_file = os.path.join(directory, 'model_energy_properties_office.json')
-    with open(dest_file, 'w') as fp:
-        json.dump(model_dict['properties']['energy'], fp, indent=4)
-
-
 def model_complete_multiroom_radiance(directory):
     triple_pane = Glass.from_single_transmittance('Triple_Pane_0.35', 0.35)
     first_floor = Room.from_box('First_Floor', 10, 10, 3, origin=Point3D(0, 0, 0))
@@ -626,7 +647,7 @@ def model_complete_multiroom_radiance(directory):
 
     model = Model('Multi_Room_Radiance_House', [first_floor, second_floor, attic])
 
-    dest_file = os.path.join(directory, 'model_complete_multiroom_radiance.json')
+    dest_file = os.path.join(directory, 'model_complete_multiroom_radiance.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(), fp, indent=4)
 
@@ -656,7 +677,7 @@ def model_radiance_grid_views(directory):
     model.properties.radiance.views = [room_view]
     model.properties.radiance.add_views([garage_view])
 
-    dest_file = os.path.join(directory, 'model_radiance_grid_views.json')
+    dest_file = os.path.join(directory, 'model_radiance_grid_views.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(included_prop=['radiance']), fp, indent=4)
 
@@ -738,7 +759,7 @@ def model_radiance_dynamic_states(directory):
 
     model_dict = model.to_dict(included_prop=['radiance'])
 
-    dest_file = os.path.join(directory, 'model_radiance_dynamic_states.json')
+    dest_file = os.path.join(directory, 'model_radiance_dynamic_states.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model_dict, fp, indent=4)
 
@@ -758,7 +779,7 @@ def model_5vertex_sub_faces(directory):
     model = Model('TinyHouse', [room])
     model_dict = model.to_dict()
 
-    dest_file = os.path.join(directory, 'model_5vertex_sub_faces.json')
+    dest_file = os.path.join(directory, 'model_5vertex_sub_faces.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model_dict, fp, indent=4)
 
@@ -787,7 +808,7 @@ def model_5vertex_sub_faces_interior(directory):
     model = Model('TinyHouse', [room1, room2])
     model_dict = model.to_dict()
 
-    dest_file = os.path.join(directory, 'model_5vertex_sub_faces_interior.json')
+    dest_file = os.path.join(directory, 'model_5vertex_sub_faces_interior.hbjson')
     with open(dest_file, 'w') as fp:
         json.dump(model_dict, fp, indent=4)
 
@@ -809,7 +830,6 @@ model_energy_no_program(sample_directory)
 model_energy_allair_hvac(sample_directory)
 model_energy_doas_hvac(sample_directory)
 model_energy_window_ac(sample_directory)
-model_energy_properties_office(sample_directory)
 model_energy_window_ventilation(sample_directory)
 model_energy_afn_multizone(sample_directory)
 model_5vertex_sub_faces(sample_directory)
